@@ -46,7 +46,7 @@ var NAVTREE =
         [ "Typedefs", "functions_type.html", null ],
         [ "Enumerations", "functions_enum.html", null ],
         [ "Enumerator", "functions_eval.html", null ],
-        [ "Related Functions", "functions_rela.html", null ]
+        [ "Related Symbols", "functions_rela.html", null ]
       ] ]
     ] ],
     [ "Files", "files.html", [
@@ -61,14 +61,14 @@ var NAVTREEINDEX =
 "a00912.html#a33f9830228f847fae1c30c9dffe02b5a",
 "a00957.html#aa7e32ce7ba896c5ddfe6521ad0022ce2",
 "a00993.html#a1d27edb01bfb68ba50776b25aa437783",
-"a01017.html#a19202138f911782b5652536867d24565",
-"a01069.html#aa71d36872f416feaa853788a7a7a7ef8",
-"a01113.html#ac5eadebfdd9b11ac383653e5a2383231",
-"a01161.html#a6a642b61f5cf7ced73523798467735a5",
-"a01205.html#ad9941ba7019b0fd8aad6e9321d91c26a",
-"a01261.html#a15628b18e19d90e91fdbd659925ae5c0",
-"a01301.html#a77cee40767fd4936f20a8f9d9d9ea625",
-"a01333.html#ab38c56ce6121aed94f2796bf5df894be"
+"a01025.html#a19202138f911782b5652536867d24565",
+"a01077.html#aa71d36872f416feaa853788a7a7a7ef8",
+"a01121.html#ac5eadebfdd9b11ac383653e5a2383231",
+"a01169.html#a6a642b61f5cf7ced73523798467735a5",
+"a01213.html#ad9941ba7019b0fd8aad6e9321d91c26a",
+"a01269.html#a15628b18e19d90e91fdbd659925ae5c0",
+"a01309.html#a77cee40767fd4936f20a8f9d9d9ea625",
+"a01341.html#ab38c56ce6121aed94f2796bf5df894be"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
